==> jquery-scrollto-1.4.5.tgz: package/README.md <==
<!-- TITLE/ -->

<h1>jQuery ScrollTo</h1>

<!-- /TITLE -->


<!-- BADGES/ -->

<span class="badge-npmversion"><a href="https://npmjs.org/package/jquery-scrollto" title="View this project on NPM"><img src="https://img.shields.io/npm/v/jquery-scrollto.svg" alt="NPM version" /></a></span>
<span class="badge-npmdownloads"><a href="https://npmjs.org/package/jquery-scrollto" title="View this project on NPM"><img src="https://img.shields.io/npm/dm/jquery-scrollto.svg" alt="NPM downloads" /></a></span>
<span class="badge-daviddm"><a href="https://david-dm.org/balupton/jquery-scrollto" title="View the status of this project's dependencies on DavidDM"><img src="https://img.shields.io/david/balupton/jquery-scrollto.svg" alt="Dependency Status" /></a></span>
<span class="badge-daviddmdev"><a href="https://david-dm.org/balupton/jquery-scrollto#info=devDependencies" title="View the status of this project's development dependencies on DavidDM"><img src="https://img.shields.io/david/dev/balupton/jquery-scrollto.svg" alt="Dev Dependency Status" /></a></span>
<br class="badge-separator" />
<span class="badge-slackin"><a href="https://slack.bevry.me" title="Join this project's slack community"><img src="https://slack.bevry.me/badge.svg" alt="Slack community badge" /></a></span>
<span class="badge-patreon"><a href="http://patreon.com/bevry" title="Donate to this project using Patreon"><img src="https://img.shields.io/badge/patreon-donate-yellow.svg" alt="Patreon donate button" /></a></span>
<span class="badge-gratipay"><a href="https://www.gratipay.com/bevry" title="Donate weekly to this project using Gratipay"><img src="https://img.shields.io/badge/gratipay-donate-yellow.svg" alt="Gratipay donate button" /></a></span>
<span class="badge-flattr"><a href="https://flattr.com/profile/balupton" title="Donate to this project using Flattr"><img src="https://img.shields.io/badge/flattr-donate-yellow.svg" alt="Flattr donate button" /></a></span>
<span class="badge-paypal"><a href="https://bevry.me/paypal" title="Donate to this project using Paypal"><img src="https://img.shields.io/badge/paypal-donate-yellow.svg" alt="PayPal donate button" /></a></span>
<span class="badge-bitcoin"><a href="https://bevry.me/bitcoin" title="Donate once-off to this project using Bitcoin"><img src="https://img.shields.io/badge/bitcoin-donate-yellow.svg" alt="Bitcoin donate button" /></a></span>
<span class="badge-wishlist"><a href="https://bevry.me/wishlist" title="Buy an item on our wishlist for us"><img src="https://img.shields.io/badge/wishlist-donate-yellow.svg" alt="Wishlist browse button" /></a></span>

<!-- /BADGES -->


<!-- DESCRIPTION/ -->

Smooth scroll to any jQuery/DOM element

<!-- /DESCRIPTION -->


<!-- INSTALL/ -->

<h2>Install</h2>

<a href="https://npmjs.com" title="npm is a package manager for javascript"><h3>NPM</h3></a><ul>
<li>Install: <code>npm install --save jquery-scrollto</code></li>
<li>Module: <code>require('jquery-scrollto')</code></li></ul>

<a href="http://browserify.org" title="Browserify lets you require('modules') in the browser by bundling up all of your dependencies"><h3>Browserify</h3></a><ul>
<li>Install: <code>npm install --save jquery-scrollto</code></li>
<li>Module: <code>require('jquery-scrollto')</code></li>
<li>CDN URL: <code>//wzrd.in/bundle/jquery-scrollto@1.4.5</code></li></ul>

<a href="http://enderjs.com" title="Ender is a full featured package manager for your browser"><h3>Ender</h3></a><ul>
<li>Install: <code>ender add jquery-scrollto</code></li>
<li>Module: <code>require('jquery-scrollto')</code></li></ul>

<!-- /INSTALL -->


### Direct
- CDN URL: `//rawgit.com/balupton/jquery-scrollto/blob/gh-pages/lib/jquery-scrollto.js`
- ZIP: https://github.com/balupton/jquery-scrollto/zipball/gh-pages


## Usage & Demo
[Refer to the demo for usage and demo](http://balupton.github.io/jquery-scrollto/)


## Download
[Download the `gh-pages` branch containing the compiled project.](https://github.com/balupton/jquery-scrollto/zipball/gh-pages)


<!-- HISTORY/ -->

<h2>History</h2>

<a href="https://github.com/balupton/jquery-scrollto/blob/master/HISTORY.md#files">Discover the release history by heading on over to the <code>HISTORY.md</code> file.</a>

<!-- /HISTORY -->


<!-- CONTRIBUTE/ -->

<h2>Contribute</h2>

<a href="https://github.com/balupton/jquery-scrollto/blob/master/CONTRIBUTING.md#files">Discover how you can contribute by heading on over to the <code>CONTRIBUTING.md</code> file.</a>

<!-- /CONTRIBUTE -->


<!-- BACKERS/ -->

<h2>Backers</h2>

<h3>Maintainers</h3>

These amazing people are maintaining this project:

<ul><li><a href="http://balupton.com">Benjamin Lupton</a> — <a href="https://github.com/balupton/jquery-scrollto/commits?author=balupton" title="View the GitHub contributions of Benjamin Lupton on repository balupton/jquery-scrollto">view contributions</a></li></ul>

<h3>Sponsors</h3>

No sponsors yet! Will you be the first?

<span class="badge-patreon"><a href="http://patreon.com/bevry" title="Donate to this project using Patreon"><img src="https://img.shields.io/badge/patreon-donate-yellow.svg" alt="Patreon donate button" /></a></span>
<span class="badge-gratipay"><a href="https://www.gratipay.com/bevry" title="Donate weekly to this project using Gratipay"><img src="https://img.shields.io/badge/gratipay-donate-yellow.svg" alt="Gratipay donate button" /></a></span>
<span class="badge-flattr"><a href="https://flattr.com/profile/balupton" title="Donate to this project using Flattr"><img src="https://img.shields.io/badge/flattr-donate-yellow.svg" alt="Flattr donate button" /></a></span>
<span class="badge-paypal"><a href="https://bevry.me/paypal" title="Donate to this project using Paypal"><img src="https://img.shields.io/badge/paypal-donate-yellow.svg" alt="PayPal donate button" /></a></span>
<span class="badge-bitcoin"><a href="https://bevry.me/bitcoin" title="Donate once-off to this project using Bitcoin"><img src="https://img.shields.io/badge/bitcoin-donate-yellow.svg" alt="Bitcoin donate button" /></a></span>
<span class="badge-wishlist"><a href="https://bevry.me/wishlist" title="Buy an item on our wishlist for us"><img src="https://img.shields.io/badge/wishlist-donate-yellow.svg" alt="Wishlist browse button" /></a></span>

<h3>Contributors</h3>

These amazing people have contributed code to this project:

<ul><li><a href="http://balupton.com">Benjamin Lupton</a> — <a href="https://github.com/balupton/jquery-scrollto/commits?author=balupton" title="View the GitHub contributions of Benjamin Lupton on repository balupton/jquery-scrollto">view contributions</a></li>
<li><a href="http://inumedia.net">Andy</a> — <a href="https://github.com/balupton/jquery-scrollto/commits?author=Inumedia" title="View the GitHub contributions of Andy on repository balupton/jquery-scrollto">view contributions</a></li>
<li><a href="http://www.peterdavehello.org/">Peter Dave Hello</a> — <a href="https://github.com/balupton/jquery-scrollto/commits?author=PeterDaveHello" title="View the GitHub contributions of Peter Dave Hello on repository balupton/jquery-scrollto">view contributions</a></li></ul>

<a href="https://github.com/balupton/jquery-scrollto/blob/master/CONTRIBUTING.md#files">Discover how you can contribute by heading on over to the <code>CONTRIBUTING.md</code> file.</a>

<!-- /BACKERS -->


<!-- LICENSE/ -->

<h2>License</h2>

Unless stated otherwise all works are:

<ul><li>Copyright &copy; 2010+ <a href="http://balupton.com">Benjamin Lupton</a></li></ul>

and licensed under:

<ul><li><a href="http://spdx.org/licenses/MIT.html">MIT License</a></li></ul>

<!-- /LICENSE -->

==> jquery-scrollto-1.4.6.tgz: package/README.md <==
<!-- TITLE/ -->

<h1>jQuery ScrollTo</h1>

<!-- /TITLE -->


<!-- BADGES/ -->

<span class="badge-npmversion"><a href="https://npmjs.org/package/jquery-scrollto" title="View this project on NPM"><img src="https://img.shields.io/npm/v/jquery-scrollto.svg" alt="NPM version" /></a></span>
<span class="badge-npmdownloads"><a href="https://npmjs.org/package/jquery-scrollto" title="View this project on NPM"><img src="https://img.shields.io/npm/dm/jquery-scrollto.svg" alt="NPM downloads" /></a></span>
<span class="badge-daviddm"><a href="https://david-dm.org/balupton/jquery-scrollto" title="View the status of this project's dependencies on DavidDM"><img src="https://img.shields.io/david/balupton/jquery-scrollto.svg" alt="Dependency Status" /></a></span>
<span class="badge-daviddmdev"><a href="https://david-dm.org/balupton/jquery-scrollto#info=devDependencies" title="View the status of this project's development dependencies on DavidDM"><img src="https://img.shields.io/david/dev/balupton/jquery-scrollto.svg" alt="Dev Dependency Status" /></a></span>
<br class="badge-separator" />
<span class="badge-slackin"><a href="https://slack.bevry.me" title="Join this project's slack community"><img src="https://slack.bevry.me/badge.svg" alt="Slack community badge" /></a></span>
<span class="badge-patreon"><a href="http://patreon.com/bevry" title="Donate to this project using Patreon"><img src="https://img.shields.io/badge/patreon-donate-yellow.svg" alt="Patreon donate button" /></a></span>
<span class="badge-gratipay"><a href="https://www.gratipay.com/bevry" title="Donate weekly to this project using Gratipay"><img src="https://img.shields.io/badge/gratipay-donate-yellow.svg" alt="Gratipay donate button" /></a></span>
<span class="badge-flattr"><a href="https://flattr.com/profile/balupton" title="Donate to this project using Flattr"><img src="https://img.shields.io/badge/flattr-donate-yellow.svg" alt="Flattr donate button" /></a></span>
<span class="badge-paypal"><a href="https://bevry.me/paypal" title="Donate to this project using Paypal"><img src="https://img.shields.io/badge/paypal-donate-yellow.svg" alt="PayPal donate button" /></a></span>
<span class="badge-bitcoin"><a href="https://bevry.me/bitcoin" title="Donate once-off to this project using Bitcoin"><img src="https://img.shields.io/badge/bitcoin-donate-yellow.svg" alt="Bitcoin donate button" /></a></span>
<span class="badge-wishlist"><a href="https://bevry.me/wishlist" title="Buy an item on our wishlist for us"><img src="https://img.shields.io/badge/wishlist-donate-yellow.svg" alt="Wishlist browse button" /></a></span>

<!-- /BADGES -->


<!-- DESCRIPTION/ -->

Smooth scroll to any jQuery/DOM element

<!-- /DESCRIPTION -->


<!-- INSTALL/ -->

<h2>Install</h2>

<a href="https://npmjs.com" title="npm is a package manager for javascript"><h3>NPM</h3></a><ul>
<li>Install: <code>npm install --save jquery-scrollto</code></li>
<li>Module: <code>require('jquery-scrollto')</code></li></ul>

<a href="http://browserify.org" title="Browserify lets you require('modules') in the browser by bundling up all of your dependencies"><h3>Browserify</h3></a><ul>
<li>Install: <code>npm install --save jquery-scrollto</code></li>
<li>Module: <code>require('jquery-scrollto')</code></li>
<li>CDN URL: <code>//wzrd.in/bundle/jquery-scrollto@1.4.6</code></li></ul>

<a href="http://enderjs.com" title="Ender is a full featured package manager for your browser"><h3>Ender</h3></a><ul>
<li>Install: <code>ender add jquery-scrollto</code></li>
<li>Module: <code>require('jquery-scrollto')</code></li></ul>

<!-- /INSTALL -->


### Direct
- CDN URL: `//rawgit.com/balupton/jquery-scrollto/blob/gh-pages/lib/jquery-scrollto.js`
- ZIP: https://github.com/balupton/jquery-scrollto/zipball/gh-pages


## Usage & Demo
[Refer to the demo for usage and demo](http://balupton.github.io/jquery-scrollto/)


<!-- HISTORY/ -->

<h2>History</h2>

<a href="https://github.com/balupton/jquery-scrollto/blob/master/HISTORY.md#files">Discover the release history by heading on over to the <code>HISTORY.md</code> file.</a>

<!-- /HISTORY -->


<!-- CONTRIBUTE/ -->

<h2>Contribute</h2>

<a href="https://github.com/balupton/jquery-scrollto/blob/master/CONTRIBUTING.md#files">Discover how you can contribute by heading on over to the <code>CONTRIBUTING.md</code> file.</a>

<!-- /CONTRIBUTE -->


<!-- BACKERS/ -->

<h2>Backers</h2>

<h3>Maintainers</h3>

These amazing people are maintaining this project:

<ul><li><a href="http://balupton.com">Benjamin Lupton</a> — <a href="https://github.com/balupton/jquery-scrollto/commits?author=balupton" title="View the GitHub contributions of Benjamin Lupton on repository balupton/jquery-scrollto">view contributions</a></li>
<li><a href="http://inumedia.net">Andy</a> — <a href="https://github.com/balupton/jquery-scrollto/commits?author=Inumedia" title="View the GitHub contributions of Andy on repository balupton/jquery-scrollto">view contributions</a></li></ul>

<h3>Sponsors</h3>

No sponsors yet! Will you be the first?

<span class="badge-patreon"><a href="http://patreon.com/bevry" title="Donate to this project using Patreon"><img src="https://img.shields.io/badge/patreon-donate-yellow.svg" alt="Patreon donate button" /></a></span>
<span class="badge-gratipay"><a href="https://www.gratipay.com/bevry" title="Donate weekly to this project using Gratipay"><img src="https://img.shields.io/badge/gratipay-donate-yellow.svg" alt="Gratipay donate button" /></a></span>
<span class="badge-flattr"><a href="https://flattr.com/profile/balupton" title="Donate to this project using Flattr"><img src="https://img.shields.io/badge/flattr-donate-yellow.svg" alt="Flattr donate button" /></a></span>
<span class="badge-paypal"><a href="https://bevry.me/paypal" title="Donate to this project using Paypal"><img src="https://img.shields.io/badge/paypal-donate-yellow.svg" alt="PayPal donate button" /></a></span>
<span class="badge-bitcoin"><a href="https://bevry.me/bitcoin" title="Donate once-off to this project using Bitcoin"><img src="https://img.shields.io/badge/bitcoin-donate-yellow.svg" alt="Bitcoin donate button" /></a></span>
<span class="badge-wishlist"><a href="https://bevry.me/wishlist" title="Buy an item on our wishlist for us"><img src="https://img.shields.io/badge/wishlist-donate-yellow.svg" alt="Wishlist browse button" /></a></span>

<h3>Contributors</h3>

These amazing people have contributed code to this project:

<ul><li><a href="http://balupton.com">Benjamin Lupton</a> — <a href="https://github.com/balupton/jquery-scrollto/commits?author=balupton" title="View the GitHub contributions of Benjamin Lupton on repository balupton/jquery-scrollto">view contributions</a></li>
<li><a href="http://inumedia.net">Andy</a> — <a href="https://github.com/balupton/jquery-scrollto/commits?author=Inumedia" title="View the GitHub contributions of Andy on repository balupton/jquery-scrollto">view contributions</a></li>
<li><a href="http://www.peterdavehello.org/">Peter Dave Hello</a> — <a href="https://github.com/balupton/jquery-scrollto/commits?author=PeterDaveHello" title="View the GitHub contributions of Peter Dave Hello on repository balupton/jquery-scrollto">view contributions</a></li></ul>

<a href="https://github.com/balupton/jquery-scrollto/blob/master/CONTRIBUTING.md#files">Discover how you can contribute by heading on over to the <code>CONTRIBUTING.md</code> file.</a>

<!-- /BACKERS -->


<!-- LICENSE/ -->

<h2>License</h2>

Unless stated otherwise all works are:

<ul><li>Copyright &copy; 2010+ <a href="http://balupton.com">Benjamin Lupton</a></li></ul>

and licensed under:

<ul><li><a href="http://spdx.org/licenses/MIT.html">MIT License</a></li></ul>

<!-- /LICENSE -->
